@@ -2,16 +2,22 @@
 # LoadCases - cLoadCases interface 
 __all__ = ['LoadCases']
 
-# import etabs namespace and error handler
-from pytabs.etabs import *
+# import ETABS namespace and pyTABS error handler
+from pytabs.etabs_config import *
 from pytabs.error_handle import *
 
 # import of interfaces of load case types
-from pytabs.case_static_nonlinear import *
-from pytabs.case_static_nonlinear_staged import *
-
-# import custom enumerations
-from pytabs.enumerations import eGeometryNonlinearityTypes
+from pytabs.case_direct_history_linear import CaseDirectHistoryLinear
+from pytabs.case_direct_history_nonlinear import CaseDirectHistoryNonlinear
+from pytabs.case_hyperstatic import CaseHyperStatic
+from pytabs.case_modal_eigen import CaseModalEigen
+from pytabs.case_modal_history_linear import CaseModalHistoryLinear
+from pytabs.case_modal_history_nonlinear import CaseModalHistoryNonlinear
+from pytabs.case_modal_ritz import CaseModalRitz
+from pytabs.case_response_spectrum import CaseResponseSpectrum
+from pytabs.case_static_linear import CaseStaticLinear
+from pytabs.case_static_nonlinear import CaseStaticNonlinear
+from pytabs.case_static_nonlinear_staged import CaseStaticNonlinearStaged
 
 # import typing
 from typing import Union
@@ -21,27 +27,37 @@ from typing import TypedDict
 class LoadCaseType(TypedDict):
     """TypedDict class for load case type return"""
     case_name : str
-    case_type : eLoadCaseType
+    case_type : etabs.eLoadCaseType
     sub_type : Union[None, str]
-    design_type : eLoadPatternType
+    design_type : etabs.eLoadPatternType
     design_type_option : str
     is_automatic : bool
 
 
 class LoadCases:
     """LoadCases interface"""
-    def __init__(self, sap_model : cSapModel) -> None:
+    def __init__(self, sap_model : etabs.cSapModel) -> None:
         # link of SapModel interface
         self.sap_model = sap_model
         # create LoadCases interface
-        self.load_cases = cLoadCases(sap_model.LoadCases)
-        # create interface for static nonlinear load cases
+        self.load_cases = etabs.cLoadCases(sap_model.LoadCases)
+        
+        # create interface for individual case types
+        self.direct_history_linear = CaseDirectHistoryLinear(sap_model)
+        self.direct_history_nonlinear = CaseDirectHistoryNonlinear(sap_model)
+        self.hyperstatic = CaseHyperStatic(sap_model)
+        self.modal_eigen = CaseModalEigen(sap_model)
+        self.modal_history_linear = CaseModalHistoryLinear(sap_model)
+        self.modal_history_nonlinear = CaseModalHistoryNonlinear(sap_model)
+        self.modal_ritz = CaseModalRitz(sap_model)
+        self.response_spectrum = CaseResponseSpectrum(sap_model)
+        self.static_linear = CaseStaticLinear(sap_model)
         self.static_nonlinear = CaseStaticNonlinear(sap_model)
-        # create interface for static nonlinear staged load cases
         self.static_nonlinear_staged = CaseStaticNonlinearStaged(sap_model)
         
-        # relate custom enumerations
-        self.eGeometryNonlinearityTypes = eGeometryNonlinearityTypes
+        # relate relevant ETABS enumerations
+        self.eLoadCaseType = etabs.eLoadCaseType
+        """EtabsModel `LoadCaseType` enumeration"""
 
 
     def change_name(self, case_name : str, new_case_name :str) -> None:
@@ -55,7 +71,7 @@ class LoadCases:
         handle(self.load_cases.ChangeName(case_name, new_case_name))
 
 
-    def count(self, case_type : Union[None, eLoadCaseType] = None) -> int:
+    def count(self, case_type : Union[None, etabs.eLoadCaseType] = None) -> int:
         """Count of load cases of type if specified.
 
         :param case_type: load case type enumeration, defaults to None
@@ -78,7 +94,7 @@ class LoadCases:
         handle(self.load_cases.Delete(case_name))
 
 
-    def get_name_list(self, case_type : Union[None, eLoadCaseType] = None) -> list[str]:
+    def get_name_list(self, case_type : Union[None, etabs.eLoadCaseType] = None) -> list[str]:
         """Retrieves the names of all defined load cases of the specified type.
 
         :param case_type: load case type enumeration, defaults to None
@@ -101,12 +117,12 @@ class LoadCases:
 
         :param case_name: name of existing load case
         :type case_name: str
-        :return: load case type, sub type and 
+        :return: load case type details
         :rtype: LoadCaseType
         """
-        case_type = eLoadCaseType.Buckling
+        case_type = etabs.eLoadCaseType.Buckling
         sub_type = int()
-        design_type = eLoadPatternType.Notional
+        design_type = etabs.eLoadPatternType.Notional
         design_type_option = int()
         is_automatic = int()
         design_type_options_desc = {0: 'Program determined', 1: 'User specified'}
@@ -125,7 +141,7 @@ class LoadCases:
                 'is_automatic': is_automatic_desc[is_automatic]}
 
 
-    def set_design_type(self, case_name : str, design_type_option : int, design_type : eLoadPatternType = eLoadPatternType.Dead) -> None:
+    def set_design_type(self, case_name : str, design_type_option : int, design_type : etabs.eLoadPatternType = etabs.eLoadPatternType.Dead) -> None:
         """Set design type of existing load case.
 
         :param case_name: name of existing load case
@@ -138,20 +154,13 @@ class LoadCases:
         handle(self.load_cases.SetDesignType(case_name, design_type_option, design_type))
         
 
-    def __determine_sub_type(self, case_type : eLoadCaseType, sub_type : int) -> Union[None, str]:
+    def __determine_sub_type(self, case_type : etabs.eLoadCaseType, sub_type : int) -> Union[None, str]:
         """Private method to determine string of load case sub type.
-
-        :param case_type: load case type
-        :type case_type: eLoadCaseType
-        :param sub_type: load case sub type integer
-        :type sub_type: int
-        :return: load case sub type description, if applicable
-        :rtype: Union[None, str]
         """
-        if int(case_type) in [int(eLoadCaseType.NonlinearStatic), int(eLoadCaseType.Modal), int(eLoadCaseType.LinearHistory)]:
-            if int(case_type) == int(eLoadCaseType.NonlinearStatic):
+        if int(case_type) in [int(etabs.eLoadCaseType.NonlinearStatic), int(etabs.eLoadCaseType.Modal), int(etabs.eLoadCaseType.LinearHistory)]:
+            if int(case_type) == int(etabs.eLoadCaseType.NonlinearStatic):
                 sub_types_dict = {1: 'Nonlinear', 2: 'Nonlinear staged construction'}
-            elif int(case_type) == int(eLoadCaseType.Modal):
+            elif int(case_type) == int(etabs.eLoadCaseType.Modal):
                 sub_types_dict = {1: 'Eigen', 2: 'Ritz'}
             else:
                 sub_types_dict = {1: 'Transient', 2: 'Periodic'}
